==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ResponsiveStateExitedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateExitedEventArgsDescription } from "./ResponsiveStateExitedEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateExitedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ResponsiveStateExitedEventArgsDescriptionMetadata, _super);
    function ResponsiveStateExitedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateExitedEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateExitedEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateExitedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateExitedEventArgsDescriptionMetadata.c(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ResponsiveStateExitedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateExitedEventArgsDescriptionMetadata.b(a);
        a.u("ResponsiveStateExitedEventArgs", function () { return new ResponsiveStateExitedEventArgsDescription(); });
        a.t("ResponsiveStateExitedEventArgs", ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.$t = markType(ResponsiveStateExitedEventArgsDescriptionMetadata, 'ResponsiveStateExitedEventArgsDescriptionMetadata');
    ResponsiveStateExitedEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateExitedEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateExitedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ResponsiveStateExitedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateExitedEventArgsDescription } from "./ResponsiveStateExitedEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateExitedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ResponsiveStateExitedEventArgsDescriptionMetadata, _super);
    function ResponsiveStateExitedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateExitedEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateExitedEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateExitedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateExitedEventArgsDescriptionMetadata.c(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ResponsiveStateExitedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateExitedEventArgsDescriptionMetadata.b(a);
        a.aa("ResponsiveStateExitedEventArgs", function () { return new ResponsiveStateExitedEventArgsDescription(); });
        a.z("ResponsiveStateExitedEventArgs", ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.$t = markType(ResponsiveStateExitedEventArgsDescriptionMetadata, 'ResponsiveStateExitedEventArgsDescriptionMetadata');
    ResponsiveStateExitedEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateExitedEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateExitedEventArgsDescriptionMetadata };
